cumulusci.tasks package
=======================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.apex
   cumulusci.tasks.bulkdata
   cumulusci.tasks.github
   cumulusci.tasks.metadata
   cumulusci.tasks.push
   cumulusci.tasks.release_notes
   cumulusci.tasks.robotframework
   cumulusci.tasks.salesforce
   cumulusci.tasks.tests

Submodules
----------


.. automodule:: cumulusci.tasks.command
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.connectedapp
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.datadictionary
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadeploy
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metaxml
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.sfdx
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks
   :members:
   :undoc-members:
   :show-inheritance:
